What
=====

ZoneMinder Python API and Logger

Limitations
============
* Only for Python3

Documentation
=================
Latest documentation is available <a href='https://pyzm.readthedocs.io/en/latest/'>here</a>

